@@ -15,23 +15,34 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""Internationalization functions."""
-
 import gettext
+import locale
 import nfoview
 
-_translation = gettext.translation(
-    "nfoview", nfoview.LOCALE_DIR, fallback=True)
+_translation = gettext.NullTranslations()
 
 
-def dgettext(domain, message):
-    """Return the localized translation of `message` from `domain`."""
-    return gettext.dgettext(domain, message)
+def bind(localedir=nfoview.LOCALE_DIR):
+    with nfoview.util.silent(Exception):
+        # Set locale to the user's default setting.
+        # Might fail on misconfigured systems.
+        locale.setlocale(locale.LC_ALL, "")
+    # Make translations available to the gettext module.
+    gettext.bindtextdomain("nfoview", localedir)
+    gettext.textdomain("nfoview")
+    with nfoview.util.silent(Exception):
+        # Make translations available to GTK+ as well.
+        # Not available on all platforms.
+        locale.bindtextdomain("nfoview", localedir)
+        locale.textdomain("nfoview")
+    globals()["_translation"] = gettext.translation(
+        "nfoview", localedir=localedir, fallback=True)
 
-def gettext(message):
-    """Return the localized translation of `message`."""
+def _(message):
     return _translation.gettext(message)
 
-def ngettext(singular, plural, n):
-    """Return the localized translation of `singular` or `plural`."""
+def d_(domain, message):
+    return gettext.dgettext(domain, message)
+
+def n_(singular, plural, n):
     return _translation.ngettext(singular, plural, n)
